@@ -5,8 +5,6 @@ use warnings;
 
 use Carp;
 
-use List::Util qw( sum );
-
 BEGIN {
     use Exporter ();
     our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
@@ -27,7 +25,7 @@ BEGIN {
 }
 
 our @EXPORT_OK;
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 =head1 NAME
 
@@ -126,7 +124,7 @@ sub new {
     return bless { @_ }, $class;
 }
 
-sub generate($) {
+sub generate {
     my ($self, $size) = @_;
     return scalar $self->{generator}->($size);
 }
@@ -134,13 +132,13 @@ sub generate($) {
 #==============================================================================
 # helpers
 
-sub defargs($@) {
+sub defargs {
     my $gen_name = shift;
     shift while ref($_[0]);  # skip template, if any
     return { %{$defaults{$gen_name}}, @_  };
 }
 
-sub template(@) {
+sub template {
     my $tmpl = [];
     push @$tmpl, shift while ref($_[0]);
     return $tmpl;
@@ -638,11 +636,18 @@ you C<use> this module.
                      glue => " " );
     # gens credit-card numbers like "4592 9459 9023 1369"
 
+    my $lgen = Paste( List( String(charset=>"0-9",length=>4)
+                          , length=>4 ), glue => " " );
+    # another way of doing the same
+
 Creates a combined generator that generates values by joining the
-values generated by each of the supplied sub-generators I<gens>.  The
-resulting string is returned.  The values are joined using the given
-glue string I<str>.  If no B<glue> modifier is provided, the default
-glue is the empty string.
+values generated by each of the supplied sub-generators I<gens>.
+(Generated list values will have their elements "flattened" into the
+rest of the generated results before joining.) The resulting string is
+returned.
+
+The values are joined using the given glue string I<str>.  If no
+B<glue> modifier is provided, the default glue is the empty string.
 
 The sizing guidance given to the combined generator will
 be passed unchanged to each of the sub-generators.
@@ -652,10 +657,7 @@ be passed unchanged to each of the sub-generators.
 sub Paste(@) {
     my @gens = @{template(@_)};
     my $glue = defargs("Paste", @_)->{glue};
-    return Gen {
-        my $size = $_[0];
-        join($glue, map {$_->generate($size)} @gens);
-    }
+    Apply( sub { join $glue, map @$_, @_ }, Flatten(@gens) );
 }
 
 =pod
@@ -715,11 +717,11 @@ B<Note:> This combinator does not accept modifiers.
 sub Frequency(@) {
     my @freqs = map {$_->[0]} @_;
     my @gens  = map {$_->[1]} @_;
-    my $total = 0;
     if ((my @baddies = grep {$_ < 0} @freqs)) {
         croak "frequencies must be non-negative; got $baddies[0]";
     }
-    $total = sum( @freqs );
+    my $total = 0;
+    $total += $_ foreach @freqs;
     unless ($total) {
         croak "at least one frequency must be greater than zero";
     }
@@ -853,7 +855,7 @@ B<Note:> This combinator does not accept modifiers.
 
 =cut
 
-# we'll use this helper in Flatten and ConcatMap
+# we'll use this helper in Flatten and ConcatMap (and Paste)
 
 sub concat(@) {
     [ map { ref($_) ? @{$_} : ($_) } @_ ];
@@ -939,7 +941,7 @@ sub ConcatMap(&@) {
 
 Creates a generator that applies the function I<fn> to each of the
 values generated by the given generators I<gen> in turn, and then
-concatenates the results.
+flattens and concatenates the results.
 
 The sizing guidance given to the combined generator will be passed
 unchanged to each sub-generator.
